@font-face {
  font-family: 'Source Code Pro';
  font-style: italic;
  font-weight: 400;
  src: url(fonts/SourceCodePro-Italic.ttf) format('truetype');
}
@font-face {
  font-family: 'Source Code Pro';
  font-style: normal;
  font-weight: 400;
  src: url(fonts/SourceCodePro-Regular.ttf) format('truetype');
}
@font-face {
  font-family: 'Source Code Pro';
  font-style: normal;
  font-weight: 600;
  src: url(fonts/SourceCodePro-SemiBold.ttf) format('truetype');
}
@font-face {
  font-family: 'Source Sans Pro';
  font-style: italic;
  font-weight: 400;
  src: url(fonts/SourceSansPro-Italic.ttf) format('truetype');
}
@font-face {
  font-family: 'Source Sans Pro';
  font-style: italic;
  font-weight: 600;
  src: url(fonts/SourceSansPro-SemiboldItalic.ttf) format('truetype');
}
@font-face {
  font-family: 'Source Sans Pro';
  font-style: normal;
  font-weight: 400;
  src: url(fonts/SourceSansPro-Regular.ttf) format('truetype');
}
@font-face {
  font-family: 'Source Sans Pro';
  font-style: normal;
  font-weight: 600;
  src: url(fonts/SourceSansPro-Semibold.ttf) format('truetype');
}
